=======
marquee
=======

marquee is a very simply Python logging formatter and handler to send log events as CloudWatch Events.

Features
--------

+ simple log formatter
+ handler to send events to CloudWatch Events

Documentation
-------------

Documentation can be found at `<http://marquee.readthedocs.io/en/latest/>`_.
